==> hoteldruid-mod-de_1.3.2-1.tar.gz: de/head.php <==
<?php

switch ($messaggio) {

case "MENU":                                             $messaggio = "HAUPTMEN&Uuml;"; break;
case "PRENOTAZIONE":                                     $messaggio = "BUCHUNG ERFASSEN"; break;
case "TABELLE":                                          $messaggio = "TABELLEN"; break;
case "GENNAIO":                                          $messaggio = "JANUAR"; break;
case "FEBBRAIO":                                         $messaggio = "FEBRUAR"; break;
case "MARZO":                                            $messaggio = "M&Auml;RZ"; break;
case "APRILE":                                           $messaggio = "APRIL"; break;
case "MAGGIO":                                           $messaggio = "MAI"; break;
case "GIUGNO":                                           $messaggio = "JUNI"; break;
case "LUGLIO":                                           $messaggio = "JULI"; break;
case "AGOSTO":                                           $messaggio = "AUGUST"; break;
case "SETTEMBRE":                                        $messaggio = "SEPTEMBER"; break;
case "OTTOBRE":                                          $messaggio = "OKTOBER"; break;
case "NOVEMBRE":                                         $messaggio = "NOVEMBER"; break;
case "DICEMBRE":                                         $messaggio = "DEZEMBER"; break;
case "PRENOTAZIONI":                                     $messaggio = "BUCHUNGSTABELLE"; break;
case "SPESE":                                            $messaggio = "ZAHLUNGEN"; break;
case "CASSE":  				$messaggio = "CASHBOXES"; break;
case "TARIFFE":                                          $messaggio = "PREISE"; break;
case "CLIENTI":                                          $messaggio = "GAST"; break;
case "INSERIRE":                                         $messaggio = "SCHNELLAUSWAHL"; break;
case "CLIENTE":                                          $messaggio = "GAST ERFASSEN"; break;
case "PREZZI":                                           $messaggio = "PREISE"; break;
case "REGOLE":                                           $messaggio = "REGELN"; break;
case "CONFIGURA":                                        $messaggio = "KONFIGURATION"; break;
case "TUTTE":                                            $messaggio = "ALLE"; break;
case "CORRENTI":                                         $messaggio = "AKTUELL"; break;
case "FUTURE":                                           $messaggio = "ZUKUNFT"; break;
case "ARRIVI":                                           $messaggio = "ANREISE"; break;
case "PARTENZE":                                         $messaggio = "ABREISE"; break;
case "MESSAGGI":                                         $messaggio = "MELDUNGEN"; break;
case "ENTRATE&nbsp;PREN.":                               $messaggio = "BUCHUNGSZAHLUNGEN"; break;
case "UTENTI":                                           $messaggio = "BENUTZER"; break;
case "SITO WEB":  			$messaggio = "WEBSITE"; break;
case "INTERCONN.":                                       $messaggio = "INTERCONN."; break;
case "BACKUP":                                           $messaggio = "DATENSICHERUNG"; break;
case "STATISTICHE":                                      $messaggio = "AUSWERTUNGEN"; break;
case "INVENTARIO":                                       $messaggio = "INVENTUR"; break;
case "CERCA":                                            $messaggio = "SUCHE"; break;
case "DOCUMENTI":                                        $messaggio = "DOKUMENTE"; break;
case "P.TO&nbsp;VENDITA":                                $messaggio = "POS"; break;
case "NUMERO":  			$messaggio = "NUMBER"; break;
case "VAI":  				$messaggio = "GO"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-de_2.1.2-1.tar.gz: de/head.php <==
<?php

switch ($messaggio) {

case "MENU":                                             $messaggio = "HAUPTMEN&Uuml;"; break;
case "PRENOTAZIONE":                                     $messaggio = "BUCHUNG ERFASSEN"; break;
case "TABELLE":                                          $messaggio = "TABELLEN"; break;
case "GENNAIO":                                          $messaggio = "JANUAR"; break;
case "FEBBRAIO":                                         $messaggio = "FEBRUAR"; break;
case "MARZO":                                            $messaggio = "M&Auml;RZ"; break;
case "MAGGIO":                                           $messaggio = "MAI"; break;
case "GIUGNO":                                           $messaggio = "JUNI"; break;
case "LUGLIO":                                           $messaggio = "JULI"; break;
case "OTTOBRE":                                          $messaggio = "OKTOBER"; break;
case "DICEMBRE":                                         $messaggio = "DEZEMBER"; break;
case "PRENOTAZIONI":                                     $messaggio = "BUCHUNGSTABELLE"; break;
case "SPESE":                                            $messaggio = "ZAHLUNGEN"; break;
case "CASSE":  			                         $messaggio = "KASSE"; break;
case "TARIFFE":                                          $messaggio = "PREISE"; break;
case "CLIENTI":                                          $messaggio = "GAST"; break;
case "INSERIRE":                                         $messaggio = "SCHNELLAUSWAHL"; break;
case "CLIENTE":                                          $messaggio = "GAST ERFASSEN"; break;
case "PREZZI":                                           $messaggio = "PREISE"; break;
case "REGOLE":                                           $messaggio = "REGELN"; break;
case "CONFIGURA":                                        $messaggio = "KONFIGURATION"; break;
case "TUTTE":                                            $messaggio = "ALLE"; break;
case "CORRENTI":                                         $messaggio = "AKTUELL"; break;
case "FUTURE":                                           $messaggio = "ZUKUNFT"; break;
case "ARRIVI":                                           $messaggio = "ANREISE"; break;
case "PARTENZE":                                         $messaggio = "ABREISE"; break;
case "MESSAGGI":                                         $messaggio = "MELDUNGEN"; break;
case "ENTRATE&nbsp;PREN.":                               $messaggio = "BUCHUNGSZAHLUNGEN"; break;
case "UTENTI":                                           $messaggio = "BENUTZER"; break;
case "SITO WEB":  		                	 $messaggio = "WEBSEITE"; break;
case "BACKUP":                                           $messaggio = "DATENSICHERUNG"; break;
case "STATISTICHE":                                      $messaggio = "AUSWERTUNGEN"; break;
case "INVENTARIO":                                       $messaggio = "INVENTUR"; break;
case "CERCA":                                            $messaggio = "SUCHE"; break;
case "DOCUMENTI":                                        $messaggio = "DOKUMENTE"; break;
case "P.TO&nbsp;VENDITA":                                $messaggio = "POS"; break;
case "NUMERO":  			                 $messaggio = "NUMMER"; break;
case "VAI":  				                 $messaggio = "GO"; break;
case "COSTI AGGIUNTIVI":  		$messaggio = "ZUSCHL&Auml;GE"; break;
case "CAPARRE E TASSE":  		$messaggio = "ANZAHL. U. STEUERN"; break;
case "APRILE":  			$messaggio = "APRIL"; break;
case "AGOSTO":  			$messaggio = "AUGUST"; break;
case "SETTEMBRE":  			$messaggio = "SEPTEMBER"; break;
case "NOVEMBRE":  			$messaggio = "NOVEMBER"; break;
case "INTERCONN.":  			$messaggio = "INTERCONN."; break;
case "PARTENZE E CORRENTI":  		$messaggio = "DEPART. AND CURRENT"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
